from builtins import zip
from builtins import object
import re
import json


def parse_json(json_path):
    replacements = []
    with open(json_path) as f:
        data = json.load(f)
        for replacement_dict in data['replacements']:
            try:
                replacements.append(Replacement(**{
                    x: replacement_dict[x]
                    for x in ('find', 'replace', 'key_path')
                    if x in replacement_dict
                }))
            except Exception as e:
                raise ValueError(
                    "Failed to parse %s (data: '%s'): %s" % (
                        json_path, replacement_dict, e))
    return replacements


def merge_two_dicts(x, y):
    z = x.copy()
    z.update(y)
    return z


class Replacement(object):
    DEFAULT_KEY_PATH = "chunks.[].archives.[].objects.[].text.[]"

    def __init__(self, find, replace, key_path=DEFAULT_KEY_PATH):
        self.find = find
        self.replace = replace
        if not isinstance(key_path, list):
            self.key_path = key_path.split('.')
        else:
            self.key_path = key_path

    def __repr__(self):
        return "s/%s/%s/g" % (self.find, self.replace)

    def correct_multiline_replacement(self, _dict):
        """
        If dealing with a multiline text block, Keynote does some bookkeeping
        with the tableParaStyle property to figure out which paragraph styles
        apply to which separate paragraphs. This method corrects for that and
        allows us to do multiline replacements.

        Fun fact: without this bookkeeping, one of these tableParaStyle indices
        might point beyond the end of the text, which causes Keynote to make
        the text box 2^16 points tall, eventually forcing it to crash.
        """
        text = _dict['text'][0]

        new_offsets = [0]

        surrogate_pair_correction = 0
        for i, c in enumerate(text):
            if c == '\n':
                new_offsets.append(i + 1 + surrogate_pair_correction)
            if ord(c) > 0xFFFF:
                surrogate_pair_correction += 1

        entries = _dict['tableParaStyle']['entries']
        if len(entries) != len(new_offsets):
            raise NotImplementedError(
                "New line count doesn't match old line count in data: %s",
                text)
        for para_entry, offset in zip(entries, new_offsets):
            para_entry['characterIndex'] = offset
        return _dict

    def correct_charstyle_replacement(self, data, key_path, depth, on_replace):
        """
        If dealing with text that contains changing styles, Keynote does
        even more bookkeeping with the tableCharStyle property to figure
        out which character styles to apply to which ranges. This method
        corrects for that and allows us to keep consistent styles on
        replaced text.

        TODO: Throw an error or print a warning if the text being
        replaced spans multiple style blocks.
        """
        new_start = 0
        text = data['text'][0]
        if 'tableCharStyle' not in data \
                or len(data['tableCharStyle']['entries']) == 1:
            old_value = data[key_path[0]]
            new_value = self.perform_on(old_value, depth + 1, on_replace)
            return merge_two_dicts(data, {key_path[0]: new_value})
        char_style_entries = data['tableCharStyle']['entries']
        parts = []
        new_indices = []
        for start, end in zip(char_style_entries, char_style_entries[1:]):
            start_index = start['characterIndex']
            end_index = end['characterIndex']
            chunk = text[start_index:end_index]
            chunk = re.sub(self.find, self.replace, chunk)
            parts.append(chunk)
            new_end = new_start + len(chunk)
            new_indices.append(new_start)
            new_start = new_end
        new_indices.append(new_indices[-1] + len(parts[-1]))
        parts.append(text[char_style_entries[-1]['characterIndex']:])
        data['text'][0] = ''.join(parts)
        for new_start, entry in zip(new_indices, char_style_entries):
            entry['characterIndex'] = new_start
        return data

    def perform_on(self, data, depth=0, on_replace=None):
        key_path = self.key_path[depth:]
        if not key_path:
            new_value = re.sub(self.find, self.replace, data)
            if new_value != data and on_replace:
                on_replace(self, data, new_value)
            return new_value
        if key_path[0] == "[]":
            return [
                self.perform_on(obj, depth + 1, on_replace)
                for obj in data
            ]
        if key_path[0] in data:
            if key_path[0] == 'text':
                output = self.correct_charstyle_replacement(
                    data, key_path, depth, on_replace)
                output = self.correct_multiline_replacement(output)
            else:
                old_value = data[key_path[0]]
                new_value = self.perform_on(old_value, depth + 1, on_replace)
                output = merge_two_dicts(data, {key_path[0]: new_value})
            return output
        else:
            return data

    def should_replace(self, data, depth=0):
        key_path = self.key_path[depth:]
        if not key_path:
            return re.search(self.find, data) is not None
        elif key_path[0] == "[]":
            return any([
                self.should_replace(obj, depth + 1) for obj in data
            ])
        elif hasattr(data, key_path[0]):
            return self.should_replace(
                getattr(data, key_path[0]), depth + 1)



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCHArchives_Common_pb2 as TSCHArchives__Common__pb2
from . import TSCHArchives_GEN_pb2 as TSCHArchives__GEN__pb2
from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2
from . import TSCHPreUFFArchives_pb2 as TSCHPreUFFArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHArchives.proto',
  package='TSCH',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x12TSCHArchives.proto\x12\x04TSCH\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSDArchives.proto\x1a\x11TSSArchives.proto\x1a\x19TSCHArchives_Common.proto\x1a\x16TSCHArchives_GEN.proto\x1a\x14TSCH3DArchives.proto\x1a\x18TSCHPreUFFArchives.proto\"F\n\x14\x43hartDrawableArchive\x12#\n\x05super\x18\x01 \x01(\x0b\x32\x14.TSD.DrawableArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"\xaf\x08\n\x0c\x43hartArchive\x12#\n\nchart_type\x18\x01 \x01(\x0e\x32\x0f.TSCH.ChartType\x12+\n\x0escatter_format\x18\x02 \x01(\x0e\x32\x13.TSCH.ScatterFormat\x12\'\n\x0clegend_frame\x18\x03 \x01(\x0b\x32\x11.TSCH.RectArchive\x12\x1e\n\x06preset\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x10series_direction\x18\x05 \x01(\x0e\x32\x15.TSCH.SeriesDirection\x12\x1d\n\x15\x63ontains_default_data\x18\x06 \x01(\x08\x12$\n\x04grid\x18\x07 \x01(\x0b\x32\x16.TSCH.ChartGridArchive\x12 \n\x08mediator\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12#\n\x0b\x63hart_style\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x63hart_non_style\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x0clegend_style\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10legend_non_style\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11value_axis_styles\x18\r \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14value_axis_nonstyles\x18\x0e \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14\x63\x61tegory_axis_styles\x18\x0f \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17\x63\x61tegory_axis_nonstyles\x18\x10 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13series_theme_styles\x18\x11 \x03(\x0b\x32\x0e.TSP.Reference\x12\x38\n\x15series_private_styles\x18\x12 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x34\n\x11series_non_styles\x18\x13 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12(\n\x10paragraph_styles\x18\x14 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12multidataset_index\x18\x15 \x01(\r\x12\x30\n(needs_calc_engine_deferred_import_action\x18\x16 \x01(\x08\x12$\n\x0cowned_preset\x18\x17 \x01(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08is_dirty\x18\x18 \x01(\x08*\t\x08\x90N\x10\x80\x80\x80\x80\x02\x32>\n\x05unity\x12\x1a.TSCH.ChartDrawableArchive\x18\x90N \x01(\x0b\x32\x12.TSCH.ChartArchive\"O\n\x1a\x43hartMultiDataIndexUpgrade21\n\x14upgraded_to_ui_state\x12\x12.TSCH.ChartArchive\x18\xa5N \x01(\x08\"\xc5\x01\n\x18\x43hartGarlicMinMaxUpgrade\x12\x16\n\x0ehorizontal_min\x18\x01 \x01(\x01\x12\x16\n\x0ehorizontal_max\x18\x02 \x01(\x01\x12\x11\n\tvalue_min\x18\x03 \x01(\x01\x12\x11\n\tvalue_max\x18\x04 \x01(\x01\x32S\n\x16garlic_min_max_upgrade\x12\x12.TSCH.ChartArchive\x18\x9aN \x01(\x0b\x32\x1e.TSCH.ChartGarlicMinMaxUpgrade\"\x9f\x02\n\x1d\x43hartGarlicLabelFormatUpgrade\x12\x14\n\x0cvalue_prefix\x18\x01 \x01(\t\x12\x14\n\x0cvalue_suffix\x18\x02 \x01(\t\x12\x1b\n\x13value_use_separator\x18\x03 \x01(\x08\x12\x19\n\x11horizontal_prefix\x18\x04 \x01(\t\x12\x19\n\x11horizontal_suffix\x18\x05 \x01(\t\x12 \n\x18horizontal_use_separator\x18\x06 \x01(\x08\x32]\n\x1bgarlic_label_format_upgrade\x12\x12.TSCH.ChartArchive\x18\x9bN \x01(\x0b\x32#.TSCH.ChartGarlicLabelFormatUpgrade\"\xe4\x01\n\x1f\x43hartPasteboardAdditionsArchive28\n\x1bpreset_index_for_pasteboard\x12\x12.TSCH.ChartArchive\x18\x90N \x01(\r27\n\x1apreset_uuid_for_pasteboard\x12\x12.TSCH.ChartArchive\x18\x91N \x01(\x0c\x32N\n!custom_format_list_for_pasteboard\x12\x12.TSCH.ChartArchive\x18\x93N \x01(\x0b\x32\x0e.TSP.Reference\"g\n\'ChartPreserveAppearanceForPresetArchive2<\n\x1f\x61ppearance_preserved_for_preset\x12\x12.TSCH.ChartArchive\x18\xa7N \x01(\x08\"}\n2ChartSupportsProportionalBendedCalloutLinesArchive2G\n*supports_proportional_bended_callout_lines\x12\x12.TSCH.ChartArchive\x18\xa8N \x01(\x08\"\x9d\x01\n\"ChartSupportsRoundedCornersArchive2@\n#deprecated_supports_rounded_corners\x12\x12.TSCH.ChartArchive\x18\xa9N \x01(\x08\x32\x35\n\x18supports_rounded_corners\x12\x12.TSCH.ChartArchive\x18\xaaN \x01(\x08\"\xad\x01\n)ChartSupportsSeriesPropertySpacingArchive2@\n#supports_series_value_label_spacing\x12\x12.TSCH.ChartArchive\x18\xabN \x01(\x08\x32>\n!supports_series_error_bar_spacing\x12\x12.TSCH.ChartArchive\x18\xacN \x01(\x08\"\xf6\x02\n\x10\x43hartGridArchive\x12\x10\n\x08row_name\x18\x01 \x03(\t\x12\x13\n\x0b\x63olumn_name\x18\x02 \x03(\t\x12\x1f\n\x08grid_row\x18\x03 \x03(\x0b\x32\r.TSCH.GridRow\x12=\n\x05idMap\x18\x04 \x01(\x0b\x32..TSCH.ChartGridArchive.ChartGridRowColumnIdMap\x1a\xda\x01\n\x17\x43hartGridRowColumnIdMap\x12H\n\nrow_id_map\x18\x01 \x03(\x0b\x32\x34.TSCH.ChartGridArchive.ChartGridRowColumnIdMap.Entry\x12K\n\rcolumn_id_map\x18\x02 \x03(\x0b\x32\x34.TSCH.ChartGridArchive.ChartGridRowColumnIdMap.Entry\x1a(\n\x05\x45ntry\x12\x10\n\x08uniqueId\x18\x01 \x02(\t\x12\r\n\x05index\x18\x02 \x02(\r\"q\n\x14\x43hartMediatorArchive\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14local_series_indexes\x18\x02 \x03(\r\x12\x1d\n\x15remote_series_indexes\x18\x03 \x03(\r\"\x8e\x01\n\x13\x43hartFillSetArchive\x12\x12\n\nidentifier\x18\x01 \x02(\t\x12\x15\n\rlookup_string\x18\x02 \x02(\t\x12%\n\x1dnumber_of_theme_series_styles\x18\x03 \x01(\r\x12%\n\rseries_styles\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\xa0\x02\n\x10\x43hartStylePreset\x12#\n\x0b\x63hart_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x0clegend_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11value_axis_styles\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14\x63\x61tegory_axis_styles\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12%\n\rseries_styles\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12(\n\x10paragraph_styles\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x0c\n\x04uuid\x18\x07 \x01(\x0c*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"}\n\x13\x43hartPresetsArchive\x12%\n\rchart_presets\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference2?\n\textension\x12\x11.TSS.ThemeArchive\x18x \x01(\x0b\x32\x19.TSCH.ChartPresetsArchive\"\x8d\x05\n$PropertyValueStorageContainerArchive\x12#\n\x0b\x63hart_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0e\x63hart_nonstyle\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x0clegend_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0flegend_nonstyle\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x11value_axis_styles\x18\x05 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x37\n\x14value_axis_nonstyles\x18\x06 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x37\n\x14\x63\x61tegory_axis_styles\x18\x07 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12:\n\x17\x63\x61tegory_axis_nonstyles\x18\x08 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x36\n\x13series_theme_styles\x18\t \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x38\n\x15series_private_styles\x18\n \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x33\n\x10series_nonstyles\x18\x0b \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x33\n\x10paragraph_styles\x18\x0c \x01(\x0b\x32\x19.TSP.SparseReferenceArray*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"\xa3\x01\n\x1aStylePasteboardDataArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive\x12\x41\n\rstyle_network\x18\x02 \x01(\x0b\x32*.TSCH.PropertyValueStorageContainerArchive\x12 \n\x18\x63opied_from_entire_chart\x18\x03 \x01(\x08\"E\n\x1d\x43hartSelectionPathTypeArchive\x12\x11\n\tpath_type\x18\x01 \x01(\t\x12\x11\n\tpath_name\x18\x02 \x01(\t\"H\n\x12\x43hartAxisIDArchive\x12!\n\taxis_type\x18\x01 \x01(\x0e\x32\x0e.TSCH.AxisType\x12\x0f\n\x07ordinal\x18\x02 \x01(\r\"^\n!ChartSelectionPathArgumentArchive\x12\x0e\n\x06number\x18\x01 \x01(\r\x12)\n\x07\x61xis_id\x18\x02 \x01(\x0b\x32\x18.TSCH.ChartAxisIDArchive\"\xc7\x01\n\x19\x43hartSelectionPathArchive\x12\x36\n\tpath_type\x18\x01 \x01(\x0b\x32#.TSCH.ChartSelectionPathTypeArchive\x12\x36\n\rsub_selection\x18\x02 \x01(\x0b\x32\x1f.TSCH.ChartSelectionPathArchive\x12:\n\targuments\x18\x03 \x03(\x0b\x32\'.TSCH.ChartSelectionPathArgumentArchive\"\x94\x01\n\x15\x43hartSelectionArchive\x12,\n\x05super\x18\x03 \x01(\x0b\x32\x1d.TSD.DrawableSelectionArchive\x12\x1d\n\x05\x63hart\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x05paths\x18\x02 \x03(\x0b\x32\x1f.TSCH.ChartSelectionPathArchive\"\xab\x01\n\x18\x43hartCDESelectionArchive\x12\x1d\n\x05\x63hart\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x16\n\x0eselection_type\x18\x02 \x01(\x05\x12\x14\n\x0crow_location\x18\x03 \x01(\r\x12\x12\n\nrow_length\x18\x04 \x01(\r\x12\x17\n\x0f\x63olumn_location\x18\x05 \x01(\r\x12\x15\n\rcolumn_length\x18\x06 \x01(\r\"\x92\x02\n\x0c\x43hartUIState\x12\x1d\n\x05\x63hart\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x15\x63\x64\x65_last_row_selected\x18\x02 \x01(\x05\x12\x1d\n\x15\x63\x64\x65_last_col_selected\x18\x03 \x01(\x05\x12\x1a\n\x12\x63\x64\x65_last_row_count\x18\x04 \x01(\x05\x12\x1a\n\x12\x63\x64\x65_last_col_count\x18\x05 \x01(\x05\x12\x1d\n\x15\x63\x64\x65_use_full_keyboard\x18\x06 \x01(\x08\x12\x1c\n\x14multi_data_set_index\x18\x07 \x01(\x05\x12%\n\x1dis_valid_multi_data_set_index\x18\x08 \x01(\x08*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"U\n!ChartUIStateMultiDataIndexUpgrade20\n\x13upgraded_from_model\x12\x12.TSCH.ChartUIState\x18\xa6N \x01(\x08\"s\n\x1b\x43hartFormatStructExtensions2)\n\x06prefix\x12\x18.TSK.FormatStructArchive\x18\x90N \x01(\t2)\n\x06suffix\x12\x18.TSK.FormatStructArchive\x18\x91N \x01(\t\"\\\n\x1e\x43hartReferenceLineNonStyleItem\x12!\n\tnon_style\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x04uuid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\"\xa1\x01\n&ChartAxisReferenceLineNonStylesArchive\x12)\n\x07\x61xis_id\x18\x01 \x02(\x0b\x32\x18.TSCH.ChartAxisIDArchive\x12L\n\x1ereference_line_non_style_items\x18\x02 \x03(\x0b\x32$.TSCH.ChartReferenceLineNonStyleItem\"\x8a\x01\n#ChartAxisReferenceLineStylesArchive\x12)\n\x07\x61xis_id\x18\x01 \x02(\x0b\x32\x18.TSCH.ChartAxisIDArchive\x12\x38\n\x15reference_line_styles\x18\x02 \x01(\x0b\x32\x19.TSP.SparseReferenceArray\"\xfa\x01\n\x1a\x43hartReferenceLinesArchive\x12S\n\x1dreference_line_non_styles_map\x18\x01 \x03(\x0b\x32,.TSCH.ChartAxisReferenceLineNonStylesArchive\x12L\n\x19reference_line_styles_map\x18\x02 \x03(\x0b\x32).TSCH.ChartAxisReferenceLineStylesArchive\x12\x39\n!theme_preset_reference_line_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"V\n%ChartPresetReferenceLineStylesArchive\x12-\n\x15reference_line_styles\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"\xa7\x01\n,ChartAxisReferenceLineSparseNonStylesArchive\x12)\n\x07\x61xis_id\x18\x01 \x02(\x0b\x32\x18.TSCH.ChartAxisIDArchive\x12L\n\x1ereference_line_non_style_items\x18\x02 \x03(\x0b\x32$.TSCH.ChartReferenceLineNonStyleItem\"\x98\x02\n2PropertyValueStorageContainerReferenceLinesArchive\x12Y\n\x1dreference_line_non_styles_map\x18\x01 \x03(\x0b\x32\x32.TSCH.ChartAxisReferenceLineSparseNonStylesArchive\x12L\n\x19reference_line_styles_map\x18\x02 \x03(\x0b\x32).TSCH.ChartAxisReferenceLineStylesArchive\x12\x39\n!theme_preset_reference_line_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference:<\n\x1fscene3d_settings_constant_depth\x12\x12.TSCH.ChartArchive\x18\x92N \x01(\x08:@\n#last_applied_fill_set_lookup_string\x12\x12.TSCH.ChartArchive\x18\x94N \x01(\t:=\n\x15series_supports_donut\x12\x1d.TSCH.ChartSeriesStyleArchive\x18\x91N \x01(\x08:O\n$series_supports_custom_number_format\x12 .TSCH.ChartSeriesNonStyleArchive\x18\x91N \x01(\x08:M\n\"series_supports_custom_date_format\x12 .TSCH.ChartSeriesNonStyleArchive\x18\x92N \x01(\x08:H\n\x1dseries_supports_callout_lines\x12 .TSCH.ChartSeriesNonStyleArchive\x18\x93N \x01(\x08:K\n\"axis_supports_custom_number_format\x12\x1e.TSCH.ChartAxisNonStyleArchive\x18\x91N \x01(\x08:I\n axis_supports_custom_date_format\x12\x1e.TSCH.ChartAxisNonStyleArchive\x18\x92N \x01(\x08:N\n\x0freference_lines\x12\x12.TSCH.ChartArchive\x18\x95N \x01(\x0b\x32 .TSCH.ChartReferenceLinesArchive:j\n\x1cpreset_reference_line_styles\x12\x16.TSCH.ChartStylePreset\x18\x90N \x01(\x0b\x32+.TSCH.ChartPresetReferenceLineStylesArchive:\x9f\x01\n0property_value_storage_container_reference_lines\x12*.TSCH.PropertyValueStorageContainerArchive\x18\x90N \x01(\x0b\x32\x38.TSCH.PropertyValueStorageContainerReferenceLinesArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCHArchives__Common__pb2.DESCRIPTOR,TSCHArchives__GEN__pb2.DESCRIPTOR,TSCH3DArchives__pb2.DESCRIPTOR,TSCHPreUFFArchives__pb2.DESCRIPTOR,])


SCENE3D_SETTINGS_CONSTANT_DEPTH_FIELD_NUMBER = 10002
scene3d_settings_constant_depth = _descriptor.FieldDescriptor(
  name='scene3d_settings_constant_depth', full_name='TSCH.scene3d_settings_constant_depth', index=0,
  number=10002, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
LAST_APPLIED_FILL_SET_LOOKUP_STRING_FIELD_NUMBER = 10004
last_applied_fill_set_lookup_string = _descriptor.FieldDescriptor(
  name='last_applied_fill_set_lookup_string', full_name='TSCH.last_applied_fill_set_lookup_string', index=1,
  number=10004, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=_b("").decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
SERIES_SUPPORTS_DONUT_FIELD_NUMBER = 10001
series_supports_donut = _descriptor.FieldDescriptor(
  name='series_supports_donut', full_name='TSCH.series_supports_donut', index=2,
  number=10001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
SERIES_SUPPORTS_CUSTOM_NUMBER_FORMAT_FIELD_NUMBER = 10001
series_supports_custom_number_format = _descriptor.FieldDescriptor(
  name='series_supports_custom_number_format', full_name='TSCH.series_supports_custom_number_format', index=3,
  number=10001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
SERIES_SUPPORTS_CUSTOM_DATE_FORMAT_FIELD_NUMBER = 10002
series_supports_custom_date_format = _descriptor.FieldDescriptor(
  name='series_supports_custom_date_format', full_name='TSCH.series_supports_custom_date_format', index=4,
  number=10002, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
SERIES_SUPPORTS_CALLOUT_LINES_FIELD_NUMBER = 10003
series_supports_callout_lines = _descriptor.FieldDescriptor(
  name='series_supports_callout_lines', full_name='TSCH.series_supports_callout_lines', index=5,
  number=10003, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
AXIS_SUPPORTS_CUSTOM_NUMBER_FORMAT_FIELD_NUMBER = 10001
axis_supports_custom_number_format = _descriptor.FieldDescriptor(
  name='axis_supports_custom_number_format', full_name='TSCH.axis_supports_custom_number_format', index=6,
  number=10001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
AXIS_SUPPORTS_CUSTOM_DATE_FORMAT_FIELD_NUMBER = 10002
axis_supports_custom_date_format = _descriptor.FieldDescriptor(
  name='axis_supports_custom_date_format', full_name='TSCH.axis_supports_custom_date_format', index=7,
  number=10002, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
REFERENCE_LINES_FIELD_NUMBER = 10005
reference_lines = _descriptor.FieldDescriptor(
  name='reference_lines', full_name='TSCH.reference_lines', index=8,
  number=10005, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
PRESET_REFERENCE_LINE_STYLES_FIELD_NUMBER = 10000
preset_reference_line_styles = _descriptor.FieldDescriptor(
  name='preset_reference_line_styles', full_name='TSCH.preset_reference_line_styles', index=9,
  number=10000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
PROPERTY_VALUE_STORAGE_CONTAINER_REFERENCE_LINES_FIELD_NUMBER = 10000
property_value_storage_container_reference_lines = _descriptor.FieldDescriptor(
  name='property_value_storage_container_reference_lines', full_name='TSCH.property_value_storage_container_reference_lines', index=10,
  number=10000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_CHARTDRAWABLEARCHIVE = _descriptor.Descriptor(
  name='ChartDrawableArchive',
  full_name='TSCH.ChartDrawableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartDrawableArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=273,
)


_CHARTARCHIVE = _descriptor.Descriptor(
  name='ChartArchive',
  full_name='TSCH.ChartArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_type', full_name='TSCH.ChartArchive.chart_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_format', full_name='TSCH.ChartArchive.scatter_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_frame', full_name='TSCH.ChartArchive.legend_frame', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSCH.ChartArchive.preset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_direction', full_name='TSCH.ChartArchive.series_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contains_default_data', full_name='TSCH.ChartArchive.contains_default_data', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grid', full_name='TSCH.ChartArchive.grid', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mediator', full_name='TSCH.ChartArchive.mediator', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_style', full_name='TSCH.ChartArchive.chart_style', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_non_style', full_name='TSCH.ChartArchive.chart_non_style', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_style', full_name='TSCH.ChartArchive.legend_style', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_non_style', full_name='TSCH.ChartArchive.legend_non_style', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_styles', full_name='TSCH.ChartArchive.value_axis_styles', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_nonstyles', full_name='TSCH.ChartArchive.value_axis_nonstyles', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_styles', full_name='TSCH.ChartArchive.category_axis_styles', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_nonstyles', full_name='TSCH.ChartArchive.category_axis_nonstyles', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_theme_styles', full_name='TSCH.ChartArchive.series_theme_styles', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_private_styles', full_name='TSCH.ChartArchive.series_private_styles', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_non_styles', full_name='TSCH.ChartArchive.series_non_styles', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_styles', full_name='TSCH.ChartArchive.paragraph_styles', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multidataset_index', full_name='TSCH.ChartArchive.multidataset_index', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_calc_engine_deferred_import_action', full_name='TSCH.ChartArchive.needs_calc_engine_deferred_import_action', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owned_preset', full_name='TSCH.ChartArchive.owned_preset', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_dirty', full_name='TSCH.ChartArchive.is_dirty', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='unity', full_name='TSCH.ChartArchive.unity', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=1347,
)


_CHARTMULTIDATAINDEXUPGRADE = _descriptor.Descriptor(
  name='ChartMultiDataIndexUpgrade',
  full_name='TSCH.ChartMultiDataIndexUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='upgraded_to_ui_state', full_name='TSCH.ChartMultiDataIndexUpgrade.upgraded_to_ui_state', index=0,
      number=10021, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1428,
)


_CHARTGARLICMINMAXUPGRADE = _descriptor.Descriptor(
  name='ChartGarlicMinMaxUpgrade',
  full_name='TSCH.ChartGarlicMinMaxUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal_min', full_name='TSCH.ChartGarlicMinMaxUpgrade.horizontal_min', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_max', full_name='TSCH.ChartGarlicMinMaxUpgrade.horizontal_max', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_min', full_name='TSCH.ChartGarlicMinMaxUpgrade.value_min', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_max', full_name='TSCH.ChartGarlicMinMaxUpgrade.value_max', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='garlic_min_max_upgrade', full_name='TSCH.ChartGarlicMinMaxUpgrade.garlic_min_max_upgrade', index=0,
      number=10010, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1628,
)


_CHARTGARLICLABELFORMATUPGRADE = _descriptor.Descriptor(
  name='ChartGarlicLabelFormatUpgrade',
  full_name='TSCH.ChartGarlicLabelFormatUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_prefix', full_name='TSCH.ChartGarlicLabelFormatUpgrade.value_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_suffix', full_name='TSCH.ChartGarlicLabelFormatUpgrade.value_suffix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_use_separator', full_name='TSCH.ChartGarlicLabelFormatUpgrade.value_use_separator', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_prefix', full_name='TSCH.ChartGarlicLabelFormatUpgrade.horizontal_prefix', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_suffix', full_name='TSCH.ChartGarlicLabelFormatUpgrade.horizontal_suffix', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_use_separator', full_name='TSCH.ChartGarlicLabelFormatUpgrade.horizontal_use_separator', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='garlic_label_format_upgrade', full_name='TSCH.ChartGarlicLabelFormatUpgrade.garlic_label_format_upgrade', index=0,
      number=10011, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1918,
)


_CHARTPASTEBOARDADDITIONSARCHIVE = _descriptor.Descriptor(
  name='ChartPasteboardAdditionsArchive',
  full_name='TSCH.ChartPasteboardAdditionsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='preset_index_for_pasteboard', full_name='TSCH.ChartPasteboardAdditionsArchive.preset_index_for_pasteboard', index=0,
      number=10000, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_uuid_for_pasteboard', full_name='TSCH.ChartPasteboardAdditionsArchive.preset_uuid_for_pasteboard', index=1,
      number=10001, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_list_for_pasteboard', full_name='TSCH.ChartPasteboardAdditionsArchive.custom_format_list_for_pasteboard', index=2,
      number=10003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=2149,
)


_CHARTPRESERVEAPPEARANCEFORPRESETARCHIVE = _descriptor.Descriptor(
  name='ChartPreserveAppearanceForPresetArchive',
  full_name='TSCH.ChartPreserveAppearanceForPresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='appearance_preserved_for_preset', full_name='TSCH.ChartPreserveAppearanceForPresetArchive.appearance_preserved_for_preset', index=0,
      number=10023, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2151,
  serialized_end=2254,
)


_CHARTSUPPORTSPROPORTIONALBENDEDCALLOUTLINESARCHIVE = _descriptor.Descriptor(
  name='ChartSupportsProportionalBendedCalloutLinesArchive',
  full_name='TSCH.ChartSupportsProportionalBendedCalloutLinesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='supports_proportional_bended_callout_lines', full_name='TSCH.ChartSupportsProportionalBendedCalloutLinesArchive.supports_proportional_bended_callout_lines', index=0,
      number=10024, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2256,
  serialized_end=2381,
)


_CHARTSUPPORTSROUNDEDCORNERSARCHIVE = _descriptor.Descriptor(
  name='ChartSupportsRoundedCornersArchive',
  full_name='TSCH.ChartSupportsRoundedCornersArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='deprecated_supports_rounded_corners', full_name='TSCH.ChartSupportsRoundedCornersArchive.deprecated_supports_rounded_corners', index=0,
      number=10025, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supports_rounded_corners', full_name='TSCH.ChartSupportsRoundedCornersArchive.supports_rounded_corners', index=1,
      number=10026, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2384,
  serialized_end=2541,
)


_CHARTSUPPORTSSERIESPROPERTYSPACINGARCHIVE = _descriptor.Descriptor(
  name='ChartSupportsSeriesPropertySpacingArchive',
  full_name='TSCH.ChartSupportsSeriesPropertySpacingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='supports_series_value_label_spacing', full_name='TSCH.ChartSupportsSeriesPropertySpacingArchive.supports_series_value_label_spacing', index=0,
      number=10027, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supports_series_error_bar_spacing', full_name='TSCH.ChartSupportsSeriesPropertySpacingArchive.supports_series_error_bar_spacing', index=1,
      number=10028, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2717,
)


_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSCH.ChartGridArchive.ChartGridRowColumnIdMap.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uniqueId', full_name='TSCH.ChartGridArchive.ChartGridRowColumnIdMap.Entry.uniqueId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSCH.ChartGridArchive.ChartGridRowColumnIdMap.Entry.index', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3054,
  serialized_end=3094,
)

_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP = _descriptor.Descriptor(
  name='ChartGridRowColumnIdMap',
  full_name='TSCH.ChartGridArchive.ChartGridRowColumnIdMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_id_map', full_name='TSCH.ChartGridArchive.ChartGridRowColumnIdMap.row_id_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_id_map', full_name='TSCH.ChartGridArchive.ChartGridRowColumnIdMap.column_id_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=3094,
)

_CHARTGRIDARCHIVE = _descriptor.Descriptor(
  name='ChartGridArchive',
  full_name='TSCH.ChartGridArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_name', full_name='TSCH.ChartGridArchive.row_name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_name', full_name='TSCH.ChartGridArchive.column_name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grid_row', full_name='TSCH.ChartGridArchive.grid_row', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idMap', full_name='TSCH.ChartGridArchive.idMap', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2720,
  serialized_end=3094,
)


_CHARTMEDIATORARCHIVE = _descriptor.Descriptor(
  name='ChartMediatorArchive',
  full_name='TSCH.ChartMediatorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='TSCH.ChartMediatorArchive.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_series_indexes', full_name='TSCH.ChartMediatorArchive.local_series_indexes', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_series_indexes', full_name='TSCH.ChartMediatorArchive.remote_series_indexes', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3096,
  serialized_end=3209,
)


_CHARTFILLSETARCHIVE = _descriptor.Descriptor(
  name='ChartFillSetArchive',
  full_name='TSCH.ChartFillSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSCH.ChartFillSetArchive.identifier', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lookup_string', full_name='TSCH.ChartFillSetArchive.lookup_string', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_theme_series_styles', full_name='TSCH.ChartFillSetArchive.number_of_theme_series_styles', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_styles', full_name='TSCH.ChartFillSetArchive.series_styles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3212,
  serialized_end=3354,
)


_CHARTSTYLEPRESET = _descriptor.Descriptor(
  name='ChartStylePreset',
  full_name='TSCH.ChartStylePreset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_style', full_name='TSCH.ChartStylePreset.chart_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_style', full_name='TSCH.ChartStylePreset.legend_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_styles', full_name='TSCH.ChartStylePreset.value_axis_styles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_styles', full_name='TSCH.ChartStylePreset.category_axis_styles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_styles', full_name='TSCH.ChartStylePreset.series_styles', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_styles', full_name='TSCH.ChartStylePreset.paragraph_styles', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCH.ChartStylePreset.uuid', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=3357,
  serialized_end=3645,
)


_CHARTPRESETSARCHIVE = _descriptor.Descriptor(
  name='ChartPresetsArchive',
  full_name='TSCH.ChartPresetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_presets', full_name='TSCH.ChartPresetsArchive.chart_presets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='extension', full_name='TSCH.ChartPresetsArchive.extension', index=0,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3647,
  serialized_end=3772,
)


_PROPERTYVALUESTORAGECONTAINERARCHIVE = _descriptor.Descriptor(
  name='PropertyValueStorageContainerArchive',
  full_name='TSCH.PropertyValueStorageContainerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_style', full_name='TSCH.PropertyValueStorageContainerArchive.chart_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_nonstyle', full_name='TSCH.PropertyValueStorageContainerArchive.chart_nonstyle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_style', full_name='TSCH.PropertyValueStorageContainerArchive.legend_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_nonstyle', full_name='TSCH.PropertyValueStorageContainerArchive.legend_nonstyle', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_styles', full_name='TSCH.PropertyValueStorageContainerArchive.value_axis_styles', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_nonstyles', full_name='TSCH.PropertyValueStorageContainerArchive.value_axis_nonstyles', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_styles', full_name='TSCH.PropertyValueStorageContainerArchive.category_axis_styles', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_nonstyles', full_name='TSCH.PropertyValueStorageContainerArchive.category_axis_nonstyles', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_theme_styles', full_name='TSCH.PropertyValueStorageContainerArchive.series_theme_styles', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_private_styles', full_name='TSCH.PropertyValueStorageContainerArchive.series_private_styles', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_nonstyles', full_name='TSCH.PropertyValueStorageContainerArchive.series_nonstyles', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_styles', full_name='TSCH.PropertyValueStorageContainerArchive.paragraph_styles', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=3775,
  serialized_end=4428,
)


_STYLEPASTEBOARDDATAARCHIVE = _descriptor.Descriptor(
  name='StylePasteboardDataArchive',
  full_name='TSCH.StylePasteboardDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.StylePasteboardDataArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_network', full_name='TSCH.StylePasteboardDataArchive.style_network', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='copied_from_entire_chart', full_name='TSCH.StylePasteboardDataArchive.copied_from_entire_chart', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4431,
  serialized_end=4594,
)


_CHARTSELECTIONPATHTYPEARCHIVE = _descriptor.Descriptor(
  name='ChartSelectionPathTypeArchive',
  full_name='TSCH.ChartSelectionPathTypeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_type', full_name='TSCH.ChartSelectionPathTypeArchive.path_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_name', full_name='TSCH.ChartSelectionPathTypeArchive.path_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4596,
  serialized_end=4665,
)


_CHARTAXISIDARCHIVE = _descriptor.Descriptor(
  name='ChartAxisIDArchive',
  full_name='TSCH.ChartAxisIDArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis_type', full_name='TSCH.ChartAxisIDArchive.axis_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='TSCH.ChartAxisIDArchive.ordinal', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4667,
  serialized_end=4739,
)


_CHARTSELECTIONPATHARGUMENTARCHIVE = _descriptor.Descriptor(
  name='ChartSelectionPathArgumentArchive',
  full_name='TSCH.ChartSelectionPathArgumentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='TSCH.ChartSelectionPathArgumentArchive.number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_id', full_name='TSCH.ChartSelectionPathArgumentArchive.axis_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4741,
  serialized_end=4835,
)


_CHARTSELECTIONPATHARCHIVE = _descriptor.Descriptor(
  name='ChartSelectionPathArchive',
  full_name='TSCH.ChartSelectionPathArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_type', full_name='TSCH.ChartSelectionPathArchive.path_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_selection', full_name='TSCH.ChartSelectionPathArchive.sub_selection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='TSCH.ChartSelectionPathArchive.arguments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4838,
  serialized_end=5037,
)


_CHARTSELECTIONARCHIVE = _descriptor.Descriptor(
  name='ChartSelectionArchive',
  full_name='TSCH.ChartSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartSelectionArchive.super', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart', full_name='TSCH.ChartSelectionArchive.chart', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paths', full_name='TSCH.ChartSelectionArchive.paths', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5040,
  serialized_end=5188,
)


_CHARTCDESELECTIONARCHIVE = _descriptor.Descriptor(
  name='ChartCDESelectionArchive',
  full_name='TSCH.ChartCDESelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart', full_name='TSCH.ChartCDESelectionArchive.chart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_type', full_name='TSCH.ChartCDESelectionArchive.selection_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_location', full_name='TSCH.ChartCDESelectionArchive.row_location', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_length', full_name='TSCH.ChartCDESelectionArchive.row_length', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_location', full_name='TSCH.ChartCDESelectionArchive.column_location', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_length', full_name='TSCH.ChartCDESelectionArchive.column_length', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5191,
  serialized_end=5362,
)


_CHARTUISTATE = _descriptor.Descriptor(
  name='ChartUIState',
  full_name='TSCH.ChartUIState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart', full_name='TSCH.ChartUIState.chart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cde_last_row_selected', full_name='TSCH.ChartUIState.cde_last_row_selected', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cde_last_col_selected', full_name='TSCH.ChartUIState.cde_last_col_selected', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cde_last_row_count', full_name='TSCH.ChartUIState.cde_last_row_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cde_last_col_count', full_name='TSCH.ChartUIState.cde_last_col_count', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cde_use_full_keyboard', full_name='TSCH.ChartUIState.cde_use_full_keyboard', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multi_data_set_index', full_name='TSCH.ChartUIState.multi_data_set_index', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_valid_multi_data_set_index', full_name='TSCH.ChartUIState.is_valid_multi_data_set_index', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=5365,
  serialized_end=5639,
)


_CHARTUISTATEMULTIDATAINDEXUPGRADE = _descriptor.Descriptor(
  name='ChartUIStateMultiDataIndexUpgrade',
  full_name='TSCH.ChartUIStateMultiDataIndexUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='upgraded_from_model', full_name='TSCH.ChartUIStateMultiDataIndexUpgrade.upgraded_from_model', index=0,
      number=10022, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5641,
  serialized_end=5726,
)


_CHARTFORMATSTRUCTEXTENSIONS = _descriptor.Descriptor(
  name='ChartFormatStructExtensions',
  full_name='TSCH.ChartFormatStructExtensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='TSCH.ChartFormatStructExtensions.prefix', index=0,
      number=10000, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suffix', full_name='TSCH.ChartFormatStructExtensions.suffix', index=1,
      number=10001, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5728,
  serialized_end=5843,
)


_CHARTREFERENCELINENONSTYLEITEM = _descriptor.Descriptor(
  name='ChartReferenceLineNonStyleItem',
  full_name='TSCH.ChartReferenceLineNonStyleItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='non_style', full_name='TSCH.ChartReferenceLineNonStyleItem.non_style', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCH.ChartReferenceLineNonStyleItem.uuid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5845,
  serialized_end=5937,
)


_CHARTAXISREFERENCELINENONSTYLESARCHIVE = _descriptor.Descriptor(
  name='ChartAxisReferenceLineNonStylesArchive',
  full_name='TSCH.ChartAxisReferenceLineNonStylesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis_id', full_name='TSCH.ChartAxisReferenceLineNonStylesArchive.axis_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_line_non_style_items', full_name='TSCH.ChartAxisReferenceLineNonStylesArchive.reference_line_non_style_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5940,
  serialized_end=6101,
)


_CHARTAXISREFERENCELINESTYLESARCHIVE = _descriptor.Descriptor(
  name='ChartAxisReferenceLineStylesArchive',
  full_name='TSCH.ChartAxisReferenceLineStylesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis_id', full_name='TSCH.ChartAxisReferenceLineStylesArchive.axis_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_line_styles', full_name='TSCH.ChartAxisReferenceLineStylesArchive.reference_line_styles', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6104,
  serialized_end=6242,
)


_CHARTREFERENCELINESARCHIVE = _descriptor.Descriptor(
  name='ChartReferenceLinesArchive',
  full_name='TSCH.ChartReferenceLinesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_line_non_styles_map', full_name='TSCH.ChartReferenceLinesArchive.reference_line_non_styles_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_line_styles_map', full_name='TSCH.ChartReferenceLinesArchive.reference_line_styles_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme_preset_reference_line_style', full_name='TSCH.ChartReferenceLinesArchive.theme_preset_reference_line_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6245,
  serialized_end=6495,
)


_CHARTPRESETREFERENCELINESTYLESARCHIVE = _descriptor.Descriptor(
  name='ChartPresetReferenceLineStylesArchive',
  full_name='TSCH.ChartPresetReferenceLineStylesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_line_styles', full_name='TSCH.ChartPresetReferenceLineStylesArchive.reference_line_styles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6497,
  serialized_end=6583,
)


_CHARTAXISREFERENCELINESPARSENONSTYLESARCHIVE = _descriptor.Descriptor(
  name='ChartAxisReferenceLineSparseNonStylesArchive',
  full_name='TSCH.ChartAxisReferenceLineSparseNonStylesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis_id', full_name='TSCH.ChartAxisReferenceLineSparseNonStylesArchive.axis_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_line_non_style_items', full_name='TSCH.ChartAxisReferenceLineSparseNonStylesArchive.reference_line_non_style_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6586,
  serialized_end=6753,
)


_PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE = _descriptor.Descriptor(
  name='PropertyValueStorageContainerReferenceLinesArchive',
  full_name='TSCH.PropertyValueStorageContainerReferenceLinesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_line_non_styles_map', full_name='TSCH.PropertyValueStorageContainerReferenceLinesArchive.reference_line_non_styles_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_line_styles_map', full_name='TSCH.PropertyValueStorageContainerReferenceLinesArchive.reference_line_styles_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme_preset_reference_line_style', full_name='TSCH.PropertyValueStorageContainerReferenceLinesArchive.theme_preset_reference_line_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6756,
  serialized_end=7036,
)

_CHARTDRAWABLEARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLEARCHIVE
_CHARTARCHIVE.fields_by_name['chart_type'].enum_type = TSCHArchives__Common__pb2._CHARTTYPE
_CHARTARCHIVE.fields_by_name['scatter_format'].enum_type = TSCHArchives__Common__pb2._SCATTERFORMAT
_CHARTARCHIVE.fields_by_name['legend_frame'].message_type = TSCHArchives__Common__pb2._RECTARCHIVE
_CHARTARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['series_direction'].enum_type = TSCHArchives__Common__pb2._SERIESDIRECTION
_CHARTARCHIVE.fields_by_name['grid'].message_type = _CHARTGRIDARCHIVE
_CHARTARCHIVE.fields_by_name['mediator'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['chart_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['chart_non_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['legend_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['legend_non_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['value_axis_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['value_axis_nonstyles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['category_axis_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['category_axis_nonstyles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['series_theme_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['series_private_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_CHARTARCHIVE.fields_by_name['series_non_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_CHARTARCHIVE.fields_by_name['paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTARCHIVE.fields_by_name['owned_preset'].message_type = TSPMessages__pb2._REFERENCE
_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP_ENTRY.containing_type = _CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP
_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP.fields_by_name['row_id_map'].message_type = _CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP_ENTRY
_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP.fields_by_name['column_id_map'].message_type = _CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP_ENTRY
_CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP.containing_type = _CHARTGRIDARCHIVE
_CHARTGRIDARCHIVE.fields_by_name['grid_row'].message_type = TSCHArchives__Common__pb2._GRIDROW
_CHARTGRIDARCHIVE.fields_by_name['idMap'].message_type = _CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP
_CHARTMEDIATORARCHIVE.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_CHARTFILLSETARCHIVE.fields_by_name['series_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSTYLEPRESET.fields_by_name['chart_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSTYLEPRESET.fields_by_name['legend_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSTYLEPRESET.fields_by_name['value_axis_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSTYLEPRESET.fields_by_name['category_axis_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSTYLEPRESET.fields_by_name['series_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSTYLEPRESET.fields_by_name['paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTPRESETSARCHIVE.fields_by_name['chart_presets'].message_type = TSPMessages__pb2._REFERENCE
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['chart_style'].message_type = TSPMessages__pb2._REFERENCE
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['chart_nonstyle'].message_type = TSPMessages__pb2._REFERENCE
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['legend_style'].message_type = TSPMessages__pb2._REFERENCE
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['legend_nonstyle'].message_type = TSPMessages__pb2._REFERENCE
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['value_axis_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['value_axis_nonstyles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['category_axis_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['category_axis_nonstyles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['series_theme_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['series_private_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['series_nonstyles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_PROPERTYVALUESTORAGECONTAINERARCHIVE.fields_by_name['paragraph_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_STYLEPASTEBOARDDATAARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_STYLEPASTEBOARDDATAARCHIVE.fields_by_name['style_network'].message_type = _PROPERTYVALUESTORAGECONTAINERARCHIVE
_CHARTAXISIDARCHIVE.fields_by_name['axis_type'].enum_type = TSCHArchives__Common__pb2._AXISTYPE
_CHARTSELECTIONPATHARGUMENTARCHIVE.fields_by_name['axis_id'].message_type = _CHARTAXISIDARCHIVE
_CHARTSELECTIONPATHARCHIVE.fields_by_name['path_type'].message_type = _CHARTSELECTIONPATHTYPEARCHIVE
_CHARTSELECTIONPATHARCHIVE.fields_by_name['sub_selection'].message_type = _CHARTSELECTIONPATHARCHIVE
_CHARTSELECTIONPATHARCHIVE.fields_by_name['arguments'].message_type = _CHARTSELECTIONPATHARGUMENTARCHIVE
_CHARTSELECTIONARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLESELECTIONARCHIVE
_CHARTSELECTIONARCHIVE.fields_by_name['chart'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSELECTIONARCHIVE.fields_by_name['paths'].message_type = _CHARTSELECTIONPATHARCHIVE
_CHARTCDESELECTIONARCHIVE.fields_by_name['chart'].message_type = TSPMessages__pb2._REFERENCE
_CHARTUISTATE.fields_by_name['chart'].message_type = TSPMessages__pb2._REFERENCE
_CHARTREFERENCELINENONSTYLEITEM.fields_by_name['non_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTREFERENCELINENONSTYLEITEM.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_CHARTAXISREFERENCELINENONSTYLESARCHIVE.fields_by_name['axis_id'].message_type = _CHARTAXISIDARCHIVE
_CHARTAXISREFERENCELINENONSTYLESARCHIVE.fields_by_name['reference_line_non_style_items'].message_type = _CHARTREFERENCELINENONSTYLEITEM
_CHARTAXISREFERENCELINESTYLESARCHIVE.fields_by_name['axis_id'].message_type = _CHARTAXISIDARCHIVE
_CHARTAXISREFERENCELINESTYLESARCHIVE.fields_by_name['reference_line_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_CHARTREFERENCELINESARCHIVE.fields_by_name['reference_line_non_styles_map'].message_type = _CHARTAXISREFERENCELINENONSTYLESARCHIVE
_CHARTREFERENCELINESARCHIVE.fields_by_name['reference_line_styles_map'].message_type = _CHARTAXISREFERENCELINESTYLESARCHIVE
_CHARTREFERENCELINESARCHIVE.fields_by_name['theme_preset_reference_line_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTPRESETREFERENCELINESTYLESARCHIVE.fields_by_name['reference_line_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTAXISREFERENCELINESPARSENONSTYLESARCHIVE.fields_by_name['axis_id'].message_type = _CHARTAXISIDARCHIVE
_CHARTAXISREFERENCELINESPARSENONSTYLESARCHIVE.fields_by_name['reference_line_non_style_items'].message_type = _CHARTREFERENCELINENONSTYLEITEM
_PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE.fields_by_name['reference_line_non_styles_map'].message_type = _CHARTAXISREFERENCELINESPARSENONSTYLESARCHIVE
_PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE.fields_by_name['reference_line_styles_map'].message_type = _CHARTAXISREFERENCELINESTYLESARCHIVE
_PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE.fields_by_name['theme_preset_reference_line_style'].message_type = TSPMessages__pb2._REFERENCE
DESCRIPTOR.message_types_by_name['ChartDrawableArchive'] = _CHARTDRAWABLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartArchive'] = _CHARTARCHIVE
DESCRIPTOR.message_types_by_name['ChartMultiDataIndexUpgrade'] = _CHARTMULTIDATAINDEXUPGRADE
DESCRIPTOR.message_types_by_name['ChartGarlicMinMaxUpgrade'] = _CHARTGARLICMINMAXUPGRADE
DESCRIPTOR.message_types_by_name['ChartGarlicLabelFormatUpgrade'] = _CHARTGARLICLABELFORMATUPGRADE
DESCRIPTOR.message_types_by_name['ChartPasteboardAdditionsArchive'] = _CHARTPASTEBOARDADDITIONSARCHIVE
DESCRIPTOR.message_types_by_name['ChartPreserveAppearanceForPresetArchive'] = _CHARTPRESERVEAPPEARANCEFORPRESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartSupportsProportionalBendedCalloutLinesArchive'] = _CHARTSUPPORTSPROPORTIONALBENDEDCALLOUTLINESARCHIVE
DESCRIPTOR.message_types_by_name['ChartSupportsRoundedCornersArchive'] = _CHARTSUPPORTSROUNDEDCORNERSARCHIVE
DESCRIPTOR.message_types_by_name['ChartSupportsSeriesPropertySpacingArchive'] = _CHARTSUPPORTSSERIESPROPERTYSPACINGARCHIVE
DESCRIPTOR.message_types_by_name['ChartGridArchive'] = _CHARTGRIDARCHIVE
DESCRIPTOR.message_types_by_name['ChartMediatorArchive'] = _CHARTMEDIATORARCHIVE
DESCRIPTOR.message_types_by_name['ChartFillSetArchive'] = _CHARTFILLSETARCHIVE
DESCRIPTOR.message_types_by_name['ChartStylePreset'] = _CHARTSTYLEPRESET
DESCRIPTOR.message_types_by_name['ChartPresetsArchive'] = _CHARTPRESETSARCHIVE
DESCRIPTOR.message_types_by_name['PropertyValueStorageContainerArchive'] = _PROPERTYVALUESTORAGECONTAINERARCHIVE
DESCRIPTOR.message_types_by_name['StylePasteboardDataArchive'] = _STYLEPASTEBOARDDATAARCHIVE
DESCRIPTOR.message_types_by_name['ChartSelectionPathTypeArchive'] = _CHARTSELECTIONPATHTYPEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisIDArchive'] = _CHARTAXISIDARCHIVE
DESCRIPTOR.message_types_by_name['ChartSelectionPathArgumentArchive'] = _CHARTSELECTIONPATHARGUMENTARCHIVE
DESCRIPTOR.message_types_by_name['ChartSelectionPathArchive'] = _CHARTSELECTIONPATHARCHIVE
DESCRIPTOR.message_types_by_name['ChartSelectionArchive'] = _CHARTSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ChartCDESelectionArchive'] = _CHARTCDESELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ChartUIState'] = _CHARTUISTATE
DESCRIPTOR.message_types_by_name['ChartUIStateMultiDataIndexUpgrade'] = _CHARTUISTATEMULTIDATAINDEXUPGRADE
DESCRIPTOR.message_types_by_name['ChartFormatStructExtensions'] = _CHARTFORMATSTRUCTEXTENSIONS
DESCRIPTOR.message_types_by_name['ChartReferenceLineNonStyleItem'] = _CHARTREFERENCELINENONSTYLEITEM
DESCRIPTOR.message_types_by_name['ChartAxisReferenceLineNonStylesArchive'] = _CHARTAXISREFERENCELINENONSTYLESARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisReferenceLineStylesArchive'] = _CHARTAXISREFERENCELINESTYLESARCHIVE
DESCRIPTOR.message_types_by_name['ChartReferenceLinesArchive'] = _CHARTREFERENCELINESARCHIVE
DESCRIPTOR.message_types_by_name['ChartPresetReferenceLineStylesArchive'] = _CHARTPRESETREFERENCELINESTYLESARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisReferenceLineSparseNonStylesArchive'] = _CHARTAXISREFERENCELINESPARSENONSTYLESARCHIVE
DESCRIPTOR.message_types_by_name['PropertyValueStorageContainerReferenceLinesArchive'] = _PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE
DESCRIPTOR.extensions_by_name['scene3d_settings_constant_depth'] = scene3d_settings_constant_depth
DESCRIPTOR.extensions_by_name['last_applied_fill_set_lookup_string'] = last_applied_fill_set_lookup_string
DESCRIPTOR.extensions_by_name['series_supports_donut'] = series_supports_donut
DESCRIPTOR.extensions_by_name['series_supports_custom_number_format'] = series_supports_custom_number_format
DESCRIPTOR.extensions_by_name['series_supports_custom_date_format'] = series_supports_custom_date_format
DESCRIPTOR.extensions_by_name['series_supports_callout_lines'] = series_supports_callout_lines
DESCRIPTOR.extensions_by_name['axis_supports_custom_number_format'] = axis_supports_custom_number_format
DESCRIPTOR.extensions_by_name['axis_supports_custom_date_format'] = axis_supports_custom_date_format
DESCRIPTOR.extensions_by_name['reference_lines'] = reference_lines
DESCRIPTOR.extensions_by_name['preset_reference_line_styles'] = preset_reference_line_styles
DESCRIPTOR.extensions_by_name['property_value_storage_container_reference_lines'] = property_value_storage_container_reference_lines
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChartDrawableArchive = _reflection.GeneratedProtocolMessageType('ChartDrawableArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTDRAWABLEARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartDrawableArchive)
  ))
_sym_db.RegisterMessage(ChartDrawableArchive)

ChartArchive = _reflection.GeneratedProtocolMessageType('ChartArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartArchive)
  ))
_sym_db.RegisterMessage(ChartArchive)

ChartMultiDataIndexUpgrade = _reflection.GeneratedProtocolMessageType('ChartMultiDataIndexUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CHARTMULTIDATAINDEXUPGRADE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartMultiDataIndexUpgrade)
  ))
_sym_db.RegisterMessage(ChartMultiDataIndexUpgrade)

ChartGarlicMinMaxUpgrade = _reflection.GeneratedProtocolMessageType('ChartGarlicMinMaxUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CHARTGARLICMINMAXUPGRADE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartGarlicMinMaxUpgrade)
  ))
_sym_db.RegisterMessage(ChartGarlicMinMaxUpgrade)

ChartGarlicLabelFormatUpgrade = _reflection.GeneratedProtocolMessageType('ChartGarlicLabelFormatUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CHARTGARLICLABELFORMATUPGRADE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartGarlicLabelFormatUpgrade)
  ))
_sym_db.RegisterMessage(ChartGarlicLabelFormatUpgrade)

ChartPasteboardAdditionsArchive = _reflection.GeneratedProtocolMessageType('ChartPasteboardAdditionsArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTPASTEBOARDADDITIONSARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartPasteboardAdditionsArchive)
  ))
_sym_db.RegisterMessage(ChartPasteboardAdditionsArchive)

ChartPreserveAppearanceForPresetArchive = _reflection.GeneratedProtocolMessageType('ChartPreserveAppearanceForPresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTPRESERVEAPPEARANCEFORPRESETARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartPreserveAppearanceForPresetArchive)
  ))
_sym_db.RegisterMessage(ChartPreserveAppearanceForPresetArchive)

ChartSupportsProportionalBendedCalloutLinesArchive = _reflection.GeneratedProtocolMessageType('ChartSupportsProportionalBendedCalloutLinesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSUPPORTSPROPORTIONALBENDEDCALLOUTLINESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSupportsProportionalBendedCalloutLinesArchive)
  ))
_sym_db.RegisterMessage(ChartSupportsProportionalBendedCalloutLinesArchive)

ChartSupportsRoundedCornersArchive = _reflection.GeneratedProtocolMessageType('ChartSupportsRoundedCornersArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSUPPORTSROUNDEDCORNERSARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSupportsRoundedCornersArchive)
  ))
_sym_db.RegisterMessage(ChartSupportsRoundedCornersArchive)

ChartSupportsSeriesPropertySpacingArchive = _reflection.GeneratedProtocolMessageType('ChartSupportsSeriesPropertySpacingArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSUPPORTSSERIESPROPERTYSPACINGARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSupportsSeriesPropertySpacingArchive)
  ))
_sym_db.RegisterMessage(ChartSupportsSeriesPropertySpacingArchive)

ChartGridArchive = _reflection.GeneratedProtocolMessageType('ChartGridArchive', (_message.Message,), dict(

  ChartGridRowColumnIdMap = _reflection.GeneratedProtocolMessageType('ChartGridRowColumnIdMap', (_message.Message,), dict(

    Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
      DESCRIPTOR = _CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP_ENTRY,
      __module__ = 'TSCHArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSCH.ChartGridArchive.ChartGridRowColumnIdMap.Entry)
      ))
    ,
    DESCRIPTOR = _CHARTGRIDARCHIVE_CHARTGRIDROWCOLUMNIDMAP,
    __module__ = 'TSCHArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.ChartGridArchive.ChartGridRowColumnIdMap)
    ))
  ,
  DESCRIPTOR = _CHARTGRIDARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartGridArchive)
  ))
_sym_db.RegisterMessage(ChartGridArchive)
_sym_db.RegisterMessage(ChartGridArchive.ChartGridRowColumnIdMap)
_sym_db.RegisterMessage(ChartGridArchive.ChartGridRowColumnIdMap.Entry)

ChartMediatorArchive = _reflection.GeneratedProtocolMessageType('ChartMediatorArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTMEDIATORARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartMediatorArchive)
  ))
_sym_db.RegisterMessage(ChartMediatorArchive)

ChartFillSetArchive = _reflection.GeneratedProtocolMessageType('ChartFillSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTFILLSETARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartFillSetArchive)
  ))
_sym_db.RegisterMessage(ChartFillSetArchive)

ChartStylePreset = _reflection.GeneratedProtocolMessageType('ChartStylePreset', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSTYLEPRESET,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartStylePreset)
  ))
_sym_db.RegisterMessage(ChartStylePreset)

ChartPresetsArchive = _reflection.GeneratedProtocolMessageType('ChartPresetsArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTPRESETSARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartPresetsArchive)
  ))
_sym_db.RegisterMessage(ChartPresetsArchive)

PropertyValueStorageContainerArchive = _reflection.GeneratedProtocolMessageType('PropertyValueStorageContainerArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTYVALUESTORAGECONTAINERARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PropertyValueStorageContainerArchive)
  ))
_sym_db.RegisterMessage(PropertyValueStorageContainerArchive)

StylePasteboardDataArchive = _reflection.GeneratedProtocolMessageType('StylePasteboardDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEPASTEBOARDDATAARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.StylePasteboardDataArchive)
  ))
_sym_db.RegisterMessage(StylePasteboardDataArchive)

ChartSelectionPathTypeArchive = _reflection.GeneratedProtocolMessageType('ChartSelectionPathTypeArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSELECTIONPATHTYPEARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSelectionPathTypeArchive)
  ))
_sym_db.RegisterMessage(ChartSelectionPathTypeArchive)

ChartAxisIDArchive = _reflection.GeneratedProtocolMessageType('ChartAxisIDArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISIDARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisIDArchive)
  ))
_sym_db.RegisterMessage(ChartAxisIDArchive)

ChartSelectionPathArgumentArchive = _reflection.GeneratedProtocolMessageType('ChartSelectionPathArgumentArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSELECTIONPATHARGUMENTARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSelectionPathArgumentArchive)
  ))
_sym_db.RegisterMessage(ChartSelectionPathArgumentArchive)

ChartSelectionPathArchive = _reflection.GeneratedProtocolMessageType('ChartSelectionPathArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSELECTIONPATHARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSelectionPathArchive)
  ))
_sym_db.RegisterMessage(ChartSelectionPathArchive)

ChartSelectionArchive = _reflection.GeneratedProtocolMessageType('ChartSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSELECTIONARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSelectionArchive)
  ))
_sym_db.RegisterMessage(ChartSelectionArchive)

ChartCDESelectionArchive = _reflection.GeneratedProtocolMessageType('ChartCDESelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTCDESELECTIONARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartCDESelectionArchive)
  ))
_sym_db.RegisterMessage(ChartCDESelectionArchive)

ChartUIState = _reflection.GeneratedProtocolMessageType('ChartUIState', (_message.Message,), dict(
  DESCRIPTOR = _CHARTUISTATE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartUIState)
  ))
_sym_db.RegisterMessage(ChartUIState)

ChartUIStateMultiDataIndexUpgrade = _reflection.GeneratedProtocolMessageType('ChartUIStateMultiDataIndexUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CHARTUISTATEMULTIDATAINDEXUPGRADE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartUIStateMultiDataIndexUpgrade)
  ))
_sym_db.RegisterMessage(ChartUIStateMultiDataIndexUpgrade)

ChartFormatStructExtensions = _reflection.GeneratedProtocolMessageType('ChartFormatStructExtensions', (_message.Message,), dict(
  DESCRIPTOR = _CHARTFORMATSTRUCTEXTENSIONS,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartFormatStructExtensions)
  ))
_sym_db.RegisterMessage(ChartFormatStructExtensions)

ChartReferenceLineNonStyleItem = _reflection.GeneratedProtocolMessageType('ChartReferenceLineNonStyleItem', (_message.Message,), dict(
  DESCRIPTOR = _CHARTREFERENCELINENONSTYLEITEM,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartReferenceLineNonStyleItem)
  ))
_sym_db.RegisterMessage(ChartReferenceLineNonStyleItem)

ChartAxisReferenceLineNonStylesArchive = _reflection.GeneratedProtocolMessageType('ChartAxisReferenceLineNonStylesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISREFERENCELINENONSTYLESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisReferenceLineNonStylesArchive)
  ))
_sym_db.RegisterMessage(ChartAxisReferenceLineNonStylesArchive)

ChartAxisReferenceLineStylesArchive = _reflection.GeneratedProtocolMessageType('ChartAxisReferenceLineStylesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISREFERENCELINESTYLESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisReferenceLineStylesArchive)
  ))
_sym_db.RegisterMessage(ChartAxisReferenceLineStylesArchive)

ChartReferenceLinesArchive = _reflection.GeneratedProtocolMessageType('ChartReferenceLinesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTREFERENCELINESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartReferenceLinesArchive)
  ))
_sym_db.RegisterMessage(ChartReferenceLinesArchive)

ChartPresetReferenceLineStylesArchive = _reflection.GeneratedProtocolMessageType('ChartPresetReferenceLineStylesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTPRESETREFERENCELINESTYLESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartPresetReferenceLineStylesArchive)
  ))
_sym_db.RegisterMessage(ChartPresetReferenceLineStylesArchive)

ChartAxisReferenceLineSparseNonStylesArchive = _reflection.GeneratedProtocolMessageType('ChartAxisReferenceLineSparseNonStylesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISREFERENCELINESPARSENONSTYLESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisReferenceLineSparseNonStylesArchive)
  ))
_sym_db.RegisterMessage(ChartAxisReferenceLineSparseNonStylesArchive)

PropertyValueStorageContainerReferenceLinesArchive = _reflection.GeneratedProtocolMessageType('PropertyValueStorageContainerReferenceLinesArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE,
  __module__ = 'TSCHArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PropertyValueStorageContainerReferenceLinesArchive)
  ))
_sym_db.RegisterMessage(PropertyValueStorageContainerReferenceLinesArchive)

ChartArchive.RegisterExtension(scene3d_settings_constant_depth)
ChartArchive.RegisterExtension(last_applied_fill_set_lookup_string)
TSCHArchives__Common__pb2.ChartSeriesStyleArchive.RegisterExtension(series_supports_donut)
TSCHArchives__Common__pb2.ChartSeriesNonStyleArchive.RegisterExtension(series_supports_custom_number_format)
TSCHArchives__Common__pb2.ChartSeriesNonStyleArchive.RegisterExtension(series_supports_custom_date_format)
TSCHArchives__Common__pb2.ChartSeriesNonStyleArchive.RegisterExtension(series_supports_callout_lines)
TSCHArchives__Common__pb2.ChartAxisNonStyleArchive.RegisterExtension(axis_supports_custom_number_format)
TSCHArchives__Common__pb2.ChartAxisNonStyleArchive.RegisterExtension(axis_supports_custom_date_format)
reference_lines.message_type = _CHARTREFERENCELINESARCHIVE
ChartArchive.RegisterExtension(reference_lines)
preset_reference_line_styles.message_type = _CHARTPRESETREFERENCELINESTYLESARCHIVE
ChartStylePreset.RegisterExtension(preset_reference_line_styles)
property_value_storage_container_reference_lines.message_type = _PROPERTYVALUESTORAGECONTAINERREFERENCELINESARCHIVE
PropertyValueStorageContainerArchive.RegisterExtension(property_value_storage_container_reference_lines)
_CHARTARCHIVE.extensions_by_name['unity'].message_type = _CHARTARCHIVE
ChartDrawableArchive.RegisterExtension(_CHARTARCHIVE.extensions_by_name['unity'])
ChartArchive.RegisterExtension(_CHARTMULTIDATAINDEXUPGRADE.extensions_by_name['upgraded_to_ui_state'])
_CHARTGARLICMINMAXUPGRADE.extensions_by_name['garlic_min_max_upgrade'].message_type = _CHARTGARLICMINMAXUPGRADE
ChartArchive.RegisterExtension(_CHARTGARLICMINMAXUPGRADE.extensions_by_name['garlic_min_max_upgrade'])
_CHARTGARLICLABELFORMATUPGRADE.extensions_by_name['garlic_label_format_upgrade'].message_type = _CHARTGARLICLABELFORMATUPGRADE
ChartArchive.RegisterExtension(_CHARTGARLICLABELFORMATUPGRADE.extensions_by_name['garlic_label_format_upgrade'])
ChartArchive.RegisterExtension(_CHARTPASTEBOARDADDITIONSARCHIVE.extensions_by_name['preset_index_for_pasteboard'])
ChartArchive.RegisterExtension(_CHARTPASTEBOARDADDITIONSARCHIVE.extensions_by_name['preset_uuid_for_pasteboard'])
_CHARTPASTEBOARDADDITIONSARCHIVE.extensions_by_name['custom_format_list_for_pasteboard'].message_type = TSPMessages__pb2._REFERENCE
ChartArchive.RegisterExtension(_CHARTPASTEBOARDADDITIONSARCHIVE.extensions_by_name['custom_format_list_for_pasteboard'])
ChartArchive.RegisterExtension(_CHARTPRESERVEAPPEARANCEFORPRESETARCHIVE.extensions_by_name['appearance_preserved_for_preset'])
ChartArchive.RegisterExtension(_CHARTSUPPORTSPROPORTIONALBENDEDCALLOUTLINESARCHIVE.extensions_by_name['supports_proportional_bended_callout_lines'])
ChartArchive.RegisterExtension(_CHARTSUPPORTSROUNDEDCORNERSARCHIVE.extensions_by_name['deprecated_supports_rounded_corners'])
ChartArchive.RegisterExtension(_CHARTSUPPORTSROUNDEDCORNERSARCHIVE.extensions_by_name['supports_rounded_corners'])
ChartArchive.RegisterExtension(_CHARTSUPPORTSSERIESPROPERTYSPACINGARCHIVE.extensions_by_name['supports_series_value_label_spacing'])
ChartArchive.RegisterExtension(_CHARTSUPPORTSSERIESPROPERTYSPACINGARCHIVE.extensions_by_name['supports_series_error_bar_spacing'])
_CHARTPRESETSARCHIVE.extensions_by_name['extension'].message_type = _CHARTPRESETSARCHIVE
TSSArchives__pb2.ThemeArchive.RegisterExtension(_CHARTPRESETSARCHIVE.extensions_by_name['extension'])
ChartUIState.RegisterExtension(_CHARTUISTATEMULTIDATAINDEXUPGRADE.extensions_by_name['upgraded_from_model'])
TSKArchives__pb2.FormatStructArchive.RegisterExtension(_CHARTFORMATSTRUCTEXTENSIONS.extensions_by_name['prefix'])
TSKArchives__pb2.FormatStructArchive.RegisterExtension(_CHARTFORMATSTRUCTEXTENSIONS.extensions_by_name['suffix'])

# @@protoc_insertion_point(module_scope)
